summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccounttreebase.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccounttreebase.cpp')
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreebase.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccounttreebase.cpp b/kmymoney2/widgets/kmymoneyaccounttreebase.cpp
index c6c5d6d..03d5c41 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreebase.cpp
+++ b/kmymoney2/widgets/kmymoneyaccounttreebase.cpp
@@ -129,8 +129,8 @@ void KMyMoneyAccountTreeBase::showValue(void)
void KMyMoneyAccountTreeBase::connectNotify(const char * /* s */)
{
// update drag and drop settings
- m_accountConnections = (tqreceivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&))) != 0);
- m_institutionConnections = (tqreceivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&))) != 0);
+ m_accountConnections = (receivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&))) != 0);
+ m_institutionConnections = (receivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&))) != 0);
setDragEnabled(m_accountConnections | m_institutionConnections);
setAcceptDrops(m_accountConnections | m_institutionConnections);
}
@@ -138,8 +138,8 @@ void KMyMoneyAccountTreeBase::connectNotify(const char * /* s */)
void KMyMoneyAccountTreeBase::disconnectNotify(const char * /* s */)
{
// update drag and drop settings
- m_accountConnections = (tqreceivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&))) != 0);
- m_institutionConnections = (tqreceivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&))) != 0);
+ m_accountConnections = (receivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&))) != 0);
+ m_institutionConnections = (receivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&))) != 0);
setDragEnabled(m_accountConnections | m_institutionConnections);
setAcceptDrops(m_accountConnections | m_institutionConnections);
}
@@ -380,7 +380,7 @@ void KMyMoneyAccountTreeBase::slotOpenFolder(void)
m_autoopenTimer.stop();
if ( m_dropItem && !m_dropItem->isOpen() ) {
m_dropItem->setOpen( TRUE );
- m_dropItem->tqrepaint();
+ m_dropItem->repaint();
}
}
@@ -450,7 +450,7 @@ void KMyMoneyAccountTreeBase::contentsDragMoveEvent(TQDragMoveEvent* e)
if (tmpRect != m_lastDropHighlighter) {
cleanItemHighlighter();
m_lastDropHighlighter = tmpRect;
- viewport()->tqrepaint(tmpRect);
+ viewport()->repaint(tmpRect);
}
}
}
@@ -497,12 +497,12 @@ void KMyMoneyAccountTreeBase::cleanItemHighlighter(void)
if(m_lastDropHighlighter.isValid()) {
TQRect rect=m_lastDropHighlighter;
m_lastDropHighlighter = TQRect();
// make sure, we tqrepaint a bit more. that's important during
// autoscroll. if we don't do that, parts of the highlighter
// do not get removed
rect.moveBy(-1, -1);
rect.setSize(rect.size() + TQSize(2,2));
- viewport()->tqrepaint(rect, true);
+ viewport()->repaint(rect, true);
}
}
@@ -684,7 +684,7 @@ void KMyMoneyAccountTreeBaseItem::adjustTotalValue(const MyMoneyMoney& diff)
{
m_totalValue += diff;
- // if the entry has no tqchildren,
+ // if the entry has no children,
// or it is the top entry
// or it is currently not open
// we need to display the value of it
@@ -497,12 +497,12 @@ void KMyMoneyAccountTreeBase::cleanItemHighlighter(void)
TQRect rect=m_lastDropHighlighter;
m_lastDropHighlighter = TQRect();
- // make sure, we tqrepaint a bit more. that's important during
+ // make sure, we repaint a bit more. that's important during
// autoscroll. if we don't do that, parts of the highlighter
// do not get removed